@@ -14,8 +14,8 @@ use Sys::Hostname;
 use Sys::Syslog;
 use Errorlog::TeeOutput;
 
-my $version = '$Id: Errorlog.pm 41392 2014-04-23 14:22:52Z anton $ ';
-our $VERSION = "1.38";
+my $version = '$Id: Errorlog.pm 43121 2015-03-25 14:05:31Z anton $ ';
+our $VERSION = "1.41";
 
 #global variable, needed for TeeOutput
 our $SELF;
@@ -45,14 +45,13 @@ sub end {
 }
 
 END {
-	my $status = $?;
+	local $? = $?;
 	return if $SELF->{fields}->{skipEND};
-	if ($status) {
+	if ($?) {
 		# call an extra 'end' method to be able to call this method from an eternally living
 		# perl interpretor such as modperl.
 		end();
 	}
-	$? = $status;
 }
 
 sub new {
@@ -127,14 +126,6 @@ sub new {
 	$logdir = $self->field('logdir');
 	$logfile = $self->field('logfile');
 
-	if ($self->{outputmodes}->{syslog}) {
-		if (openlog($0, 'cons,pid', $self->{fields}->{facility}) ) {
-			$params{'syslog'} = 1; 
-		} else {
-			$self->error("Could not open syslog");
-		}
-	}
-
 	if ($self->{fields}->{noDebug2Syslog}) {
 		if ($Baseobject::verbosity >= 2) {
 			if ($self->{outputmodes}->{syslog}) {
@@ -143,11 +134,17 @@ sub new {
 				$self->{outputmodes}->{logfile} = 1;
 				syslog('debug', $syslogSuppressed);
 				$self->{outputmodes}->{syslog} = 0;
-				closelog();
 			}
 		}
 	}
 
+	if ($self->{outputmodes}->{syslog}) {
+		if (openlog($0, 'cons,pid', $self->{fields}->{facility}) ) {
+			$params{'syslog'} = 1; 
+		} else {
+			$self->error("Could not open syslog");
+		}
+	}
 
 	if ($self->{outputmodes}->{logfile}) {
 		my $file = "$logdir/$logfile";
@@ -157,12 +154,13 @@ sub new {
 		unless (-w $file) {
 			my $fh = new IO::File($file, O_WRONLY|O_CREAT|O_APPEND, $filePermissions);
 			unless ($fh) {
-				carp "WARNING: Could not open file: $file, $!. No logging to logfile will occur. Output to stderr forced";
+				my $panic = "ERROR: Could not open file: $file, $!. No logging to logfile will occur. Output to stderr forced";
+				carp $panic;
 				# make sure stderr is not lost
 				$self->{outputmodes}->{stderr} = 1;
 				$self->{outputmodes}->{logfile} = 0;
-				$fh->write("blah");
 			} else {
+				# cannot write, so close file handle
 				$fh->close;
 			}
 		}
@@ -404,17 +402,17 @@ sub banner {
 }
 
 sub mail {
-	my $self=shift;
-	my $string=join ("\n",@_);
+	my $self = shift;
+	my $string = join("\n",@_);
 	carp "Sending mail to: $self->{fields}->{mailto}" ;
-	carp "using mailprog: $self->{fields}->{mailprogram}" if ($Baseobject::verbosity >=2 );
+	carp "using mailprog: $self->{fields}->{mailprogram}" if $Baseobject::verbosity >=2 ;
 
 	unless ($self->{fields}->{mailto}) {
 		carp "ERROR: No mail send, 'mailto' not set!";
 		return;
 	}
 
-	my $mailhandle=new FileHandle();
+	my $mailhandle = new FileHandle();
 
 	if (open($mailhandle , "|-", "$self->{fields}->{mailprogram}",
 			   "-f $self->{fields}->{mailerrorsto}",
@@ -443,8 +441,8 @@ sub mail {
 #    carp ("Errorlog mailed to $self->{fields}->{mailto}\n$string\n");
 
 	} else {
-		carp( "Could not open mail: $self->{fields}->{mailprogram}, $!");
-		carp( "trying to mail: $string\n");
+		carp("Could not open mail: $self->{fields}->{mailprogram}, $!");
+		carp("trying to mail: $string\n");
 	}
 }
 
@@ -463,7 +461,7 @@ sub presentstackframe {
 	if ($Baseobject::verbosity<4) {
 		@stack = grep(!/$skip/, split("\n",$longmess));
 	} else {
-		@stack=split("\n",$longmess)
+		@stack = split("\n",$longmess)
 	}
 
 	return "" unless @stack;
@@ -500,11 +498,12 @@ sub overrule {
 
 	return unless $configdir;
 	if (-d $configdir) {
-		foreach $basepart ('defaults', $self->basefilename(),'overrule') {
+		foreach $basepart ('defaults', $self->basefilename(), 'overrule') {
 			$configfile = "$configdir/${basepart}_errorlog.cf";
 			next unless -r $configfile;
-			carp "Using additional configfile: $configfile"; #if $Baseobject::verbosity >=2 ;
-			unless (open ($fh,$configfile)) {
+			carp "Using additional configfile: $configfile" if $Baseobject::verbosity >= 2 ;
+
+			unless (open ($fh, $configfile)) {
 				carp "Found but could not open configfile: $configfile, $!";
 				return;
 			}
@@ -520,14 +519,19 @@ sub overrule {
 #				carp $self->inspect($name, $value, $split,\@values);
 
 				if ($name eq 'verbosity') {
-					carp "Configfile: $configfile, verbosity: $value";
 					verbosity($value);
-					freezeverbosity(1) if $split eq '=';
+					my $froozen = '';
+					if ($split eq '=') {
+						freezeverbosity(1);
+						$froozen = '(froozen)';
+					}
+
+					carp "Configfile: $configfile, verbosity: $value " if $Baseobject::verbosity >= 2;
 					next;
 				}
 
 				my $ref = ref($self->field($name));
-				#the target expects an array
+				# the target expects an array
 				if ($ref eq 'ARRAY') {
 					if ($split eq '=') {
 						# carp "overwriting with \"@values\"";
@@ -542,7 +546,7 @@ sub overrule {
 				elsif  ($ref eq '') {
 					$self->field($name,$value);
 				} else {
-					carp "ignoring variable: $name: type \"$ref\" not (yet:) supported";
+					carp "ignoring variable: $name: type \"$ref\" not supported";
 				}
 			}
 			warn "Errorlog (version: $VERSION): Using configfile: $configfile" 
@@ -621,6 +625,8 @@ in the new() call.
 
 Baseobject.pm Carp.pm TeeOutput.pm
 
+=over 1
+
 =item EXAMPLE
 
 NOTE in the next example @prefix@ and @localstatedir@ are considered
@@ -664,6 +670,8 @@ The output I<directed to stderr> contains the hostname and $0 (the perl
 programname) for each output line. This is not the case for all other
 outputstreams, as can be observed in the above example.
 
+=back
+
 =head1 new()
 
 =head1 SYNOPSIS
